@@ -11,13 +11,19 @@ _LOGGING_HANDLER = None
 
 def get_call_context(
     x_connect_installation_id: str = Header(None),
-    x_connect_user_id: str = Header(),
-    x_connect_account_id: str = Header(),
-    x_connect_account_role: str = Header(),
-    x_connect_call_source: str = Header(),
-    x_connect_call_type: str = Header(),
+    x_connect_user_id: str = Header(None),
+    x_connect_account_id: str = Header(None),
+    x_connect_account_role: str = Header(None),
+    x_connect_call_source: str = Header(None),
+    x_connect_call_type: str = Header(None),
+    x_connect_extension_id: str = Header(None),
+    x_connect_environment_id: str = Header(None),
+    x_connect_environment_type: str = Header(None),
 ) -> Context:
     return Context(
+        extension_id=x_connect_extension_id,
+        environment_id=x_connect_environment_id,
+        environment_type=x_connect_environment_type,
         installation_id=x_connect_installation_id,
         user_id=x_connect_user_id,
         account_id=x_connect_account_id,
