@@ -9,6 +9,9 @@ class Context(BaseModel):
 
     **Attributes:**
 
+    * **extension_id** - id of this extension.
+    * **environment_id** - id of the environment into which this extension is running.
+    * **environment_type** - type of the environment into which this extension is running.
     * **installation_id** - id of the installation object owned by the current caller.
     * **user_id** - id of the user or service user that is doing the call.
     * **account_id** - id of the account that is doing the call.
@@ -18,10 +21,12 @@ class Context(BaseModel):
     * **call_type** - it can be `admin` if the call came from the same account
         that own the extension otherwise `user`.
     """
-
+    extension_id: Optional[str]
+    environment_id: Optional[str]
+    environment_type: Optional[Literal['development', 'test', 'production']]
     installation_id: Optional[str] = None
-    user_id: str
-    account_id: str
-    account_role: str
-    call_source: Literal['ui', 'api']
-    call_type: Literal['admin', 'user']
+    user_id: Optional[str]
+    account_id: Optional[str]
+    account_role: Optional[str]
+    call_source: Optional[Literal['ui', 'api']]
+    call_type: Optional[Literal['admin', 'user']]
